@@ -26,11 +26,13 @@ from roboidai._image._object_detector import ObjectDetector
 from roboidai._image._face_marker import FaceMarkerDetector
 from roboidai._image._face_mesh import FaceMesh
 from roboidai._image._hand_pose import HandPose
+from roboidai._image._body_pose import BodyPose
+from roboidai._image._body_segmentation import BodySegmentation
 from roboidai._image._tool import ImageTool
 from roboidai._tm._image import TmImage
 from roboidai._ml._knn import Knn
 
-__version__ = "1.1.13"
+__version__ = "1.1.16"
 
 def version():
     import roboid
