@@ -17,6 +17,7 @@
 # Boston, MA  02111-1307  USA
 
 import roboidai.lab._image as _image
+import roboidai.lab._fruit_detector as _fruit_detector
 import roboidai.lab._line_recorder as _line_recorder
 import roboidai.lab._q_world as _q_world
 from roboidai.lab._q_world import QWorld
@@ -34,6 +35,9 @@ def collect_color(cam, labels, color_space='hsv'):
 def capture_color(cam, color_space='hsv'):
     return _image.capture_color(cam, color_space)
 
+def wait_until_fruit(cam, fruits, interval_msec=1):
+    return _fruit_detector.wait_until_fruit(cam, fruits, interval_msec)
+
 def record_hamster(file_path):
     _line_recorder.record_hamster(file_path)
 
